==> openshift-model-6.3.0-sources.jar: io/fabric8/openshift/api/model/RoutePortFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.IntOrStringFluent;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface RoutePortFluent<A extends RoutePortFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildTargetPort instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getTargetPort();
  public IntOrString buildTargetPort();
  public A withTargetPort(IntOrString targetPort);
  public Boolean hasTargetPort();
  public A withNewTargetPort(Object value);
  public RoutePortFluent.TargetPortNested<A> withNewTargetPort();
  public RoutePortFluent.TargetPortNested<A> withNewTargetPortLike(IntOrString item);
  public RoutePortFluent.TargetPortNested<A> editTargetPort();
  public RoutePortFluent.TargetPortNested<A> editOrNewTargetPort();
  public RoutePortFluent.TargetPortNested<A> editOrNewTargetPortLike(IntOrString item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface TargetPortNested<N> extends Nested<N>,IntOrStringFluent<RoutePortFluent.TargetPortNested<N>>{
    public N and();
    public N endTargetPort();
    
  }
  
}

==> openshift-model-6.7.1-sources.jar: io/fabric8/openshift/api/model/RoutePortFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringFluent;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RoutePortFluent<A extends RoutePortFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildTargetPort instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getTargetPort();
  public IntOrString buildTargetPort();
  public A withTargetPort(IntOrString targetPort);
  public Boolean hasTargetPort();
  public A withNewTargetPort(Object value);
  public RoutePortFluent.TargetPortNested<A> withNewTargetPort();
  public RoutePortFluent.TargetPortNested<A> withNewTargetPortLike(IntOrString item);
  public RoutePortFluent.TargetPortNested<A> editTargetPort();
  public RoutePortFluent.TargetPortNested<A> editOrNewTargetPort();
  public RoutePortFluent.TargetPortNested<A> editOrNewTargetPortLike(IntOrString item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface TargetPortNested<N> extends Nested<N>,IntOrStringFluent<RoutePortFluent.TargetPortNested<N>>{
    public N and();
    public N endTargetPort();
    
  }
  
}
